==> mdm-rpc-0.0.31-sources.jar: com/chinayanghe/msp/mdm/vo/productSale/TmProductSaleOldCodeVo.java <==
package com.chinayanghe.msp.mdm.vo.productSale;

import java.io.Serializable;

/**
 * 商品编码和老商品编码对应关系实体类
 * @author : TRivers chen
 * @className : yh-cost-main.com.biz.eisp.mdm.productSale.entity.TmProductSaleOldCodeEntity
 * @createtime : 2017/5/814:35
 */
public class TmProductSaleOldCodeVo implements Serializable{

    private static final long serialVersionUID = -6245463570197649036L;

    private String id;
    /**
     *商品编码
     */
    private String productSaleCode;
    /**
     *老商品编码
     */
    private String oldProductSaleCode ;
    /**
     *商品信息，对应tm_product_sale表produc_sale_code编码
     */
    private ProductSaleVo productSaleVo;


    public String getId() {
        return this.id;
    }

    public void setId(String id) {
        this.id = id;
    }

    /**
     *商品编码
     */
    public String getProductSaleCode() {
        return this.productSaleCode;
    }

    /**
     *商品编码
     */
    public void setProductSaleCode(String productSaleCode) {
        this.productSaleCode = productSaleCode;
    }

    /**
     *老商品编码
     */
    public String getOldProductSaleCode() {
        return this.oldProductSaleCode;
    }

    /**
     *老商品编码
     */
    public void setOldProductSaleCode(String oldProductSaleCode) {
        this.oldProductSaleCode = oldProductSaleCode;
    }

    /**
     *商品信息，对应tm_product_sale表produc_sale_code编码
     */
    public ProductSaleVo getProductSaleVo() {
        return this.productSaleVo;
    }

    /**
     *商品信息，对应tm_product_sale表produc_sale_code编码
     */
    public void setProductSaleDto(ProductSaleVo productSaleDto) {
        this.productSaleVo = productSaleDto;
    }
}

==> mdm-rpc-0.1.11-sources.jar: com/chinayanghe/msp/mdm/vo/productSale/TmProductSaleOldCodeVo.java <==
package com.chinayanghe.msp.mdm.vo.productSale;

import java.io.Serializable;

/**
 * 商品编码和老商品编码对应关系实体类
 * @author : TRivers chen
 * @className : yh-cost-main.com.biz.eisp.mdm.productSale.entity.TmProductSaleOldCodeEntity
 * @createtime : 2017/5/814:35
 */
public class TmProductSaleOldCodeVo implements Serializable{

    private Integer id;
    /**
     *商品编码
     */
    private String productSaleCode;
    /**
     *老商品编码
     */
    private String oldProductSaleCode ;
    /**
     *商品信息，对应tm_product_sale表produc_sale_code编码
     */
    private ProductSaleVo productSaleVo;


    public Integer getId() {
        return this.id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    /**
     *商品编码
     */
    public String getProductSaleCode() {
        return this.productSaleCode;
    }

    /**
     *商品编码
     */
    public void setProductSaleCode(String productSaleCode) {
        this.productSaleCode = productSaleCode;
    }

    /**
     *老商品编码
     */
    public String getOldProductSaleCode() {
        return this.oldProductSaleCode;
    }

    /**
     *老商品编码
     */
    public void setOldProductSaleCode(String oldProductSaleCode) {
        this.oldProductSaleCode = oldProductSaleCode;
    }

    /**
     *商品信息，对应tm_product_sale表produc_sale_code编码
     */
    public ProductSaleVo getProductSaleVo() {
        return this.productSaleVo;
    }

    /**
     *商品信息，对应tm_product_sale表produc_sale_code编码
     */
    public void setProductSaleDto(ProductSaleVo productSaleDto) {
        this.productSaleVo = productSaleDto;
    }
}
